/*-- 

 Copyright (C) 2001 Anthony Eden.
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:
 
 1. Redistributions of source code must retain the above copyright
    notice, this list of conditions, and the following disclaimer.
 
 2. Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions, and the disclaimer that follows 
    these conditions in the documentation and/or other materials 
    provided with the distribution.

 3. The name "JPublish" must not be used to endorse or promote products
    derived from this software without prior written permission.  For
    written permission, please contact me@anthonyeden.com.
 
 4. Products derived from this software may not be called "JPublish", nor
    may "JPublish" appear in their name, without prior written permission
    from Anthony Eden (me@anthonyeden.com).
 
 In addition, I request (but do not require) that you include in the 
 end-user documentation provided with the redistribution and/or in the 
 software itself an acknowledgement equivalent to the following:
     "This product includes software developed by
      Anthony Eden (http://www.anthonyeden.com/)."

 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR(S) BE LIABLE FOR ANY DIRECT, 
 INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES 
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR 
 SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) 
 HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, 
 STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING 
 IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 POSSIBILITY OF SUCH DAMAGE.

 For more information on JPublish, please see <http://www.jpublish.org/>.
 
 */

package org.jpublish;

import org.apache.velocity.VelocityContext;

/**	A common interface which all repositories must implement.  A Repository
	represents a data store which contains content.

	@author Anthony Eden
*/

public interface Repository extends Configurable{

	/**	Get the name of the repository.  This name is used to expose the
		Repository in the Velocity engine.
		
		@return The Repository name
	*/

	public String getName();

	/**	Get the content from the given path.  Implementations of this method
		should NOT merge the content using Velocity.
	
		@param path The relative content path
		@return The content as a String
		@throws Exception Any Exception
	*/

	public String get(String path) throws Exception;
	
	/**	Get the content from the given path and merge it with
		the given context.
		
		@param path The content path
		@param context The VelocityContext
		@return The content as a String
		@throws Exception Any Exception
	*/
	
	public String get(String path, VelocityContext context) throws Exception;
	
	/**	Get the last modified time in milliseconds for the given path.
	
		@param path The content path
		@return The last modified time in milliseconds
		@throws Exception Any Exception
	*/
	
	public long getLastModified(String path) throws Exception;
	
	/**	Set the SiteContext.  The repository can then get information 
		about the site through the context.
	
		@param siteContext The siteContext
	*/
	
	public void setSiteContext(SiteContext siteContext);

}
