/*-- 

 Copyright (C) 2001 Anthony Eden.
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:
 
 1. Redistributions of source code must retain the above copyright
    notice, this list of conditions, and the following disclaimer.
 
 2. Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions, and the disclaimer that follows 
    these conditions in the documentation and/or other materials 
    provided with the distribution.

 3. The name "JPublish" must not be used to endorse or promote products
    derived from this software without prior written permission.  For
    written permission, please contact me@anthonyeden.com.
 
 4. Products derived from this software may not be called "JPublish", nor
    may "JPublish" appear in their name, without prior written permission
    from Anthony Eden (me@anthonyeden.com).
 
 In addition, I request (but do not require) that you include in the 
 end-user documentation provided with the redistribution and/or in the 
 software itself an acknowledgement equivalent to the following:
     "This product includes software developed by
      Anthony Eden (http://www.anthonyeden.com/)."

 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR(S) BE LIABLE FOR ANY DIRECT, 
 INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES 
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR 
 SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) 
 HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, 
 STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING 
 IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 POSSIBILITY OF SUCH DAMAGE.

 For more information on JPublish, please see <http://www.jpublish.org/>.
 
 */

package org.jpublish;

import org.apache.velocity.VelocityContext;

/**	A wrapper around any repository.  This wrapper is used to expose the
	Repository to the Velocity engine.  The current context is stored when
	the wrapper is created.
	
	@author Anthony Eden
*/

public class RepositoryWrapper{

	/**	Construct a new RepositoryWrapper over the given repository using
		the given context for merging.
		
		@param repository The repository
		@param context The VelocityContext
	*/

	public RepositoryWrapper(Repository repository, VelocityContext context){
		this.repository = repository;
		this.context = context;
	}
	
	/**	Get the content at the given path.  The content will be merged
		with the associated VelocityContext.
	
		@param path The content path
		@return The content as a String
	*/
	
	public String get(String path){
		return get(path, true);
	}
	
	/**	Get the content at the given path, optinally merging it with the
		associated VelocityContext.  If merge is true then merging will
		occur.  Errors will be caught and the error message will be returned
		in place of the content.
		
		@param path The content path
		@param merge True to merge
		@return The content as a String
	*/
	
	public String get(String path, boolean merged){
		try{
			if(merged){
				return repository.get(path, context);
			} else {
				return repository.get(path);
			}
		} catch(Exception e){	
			e.printStackTrace();
			return "Error: " + e.getMessage();
		}
	}
	
	private Repository repository;
	private VelocityContext context;

}
