/*-- 

 Copyright (C) 2001 Anthony Eden.
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:
 
 1. Redistributions of source code must retain the above copyright
    notice, this list of conditions, and the following disclaimer.
 
 2. Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions, and the disclaimer that follows 
    these conditions in the documentation and/or other materials 
    provided with the distribution.

 3. The name "JPublish" must not be used to endorse or promote products
    derived from this software without prior written permission.  For
    written permission, please contact me@anthonyeden.com.
 
 4. Products derived from this software may not be called "JPublish", nor
    may "JPublish" appear in their name, without prior written permission
    from Anthony Eden (me@anthonyeden.com).
 
 In addition, I request (but do not require) that you include in the 
 end-user documentation provided with the redistribution and/or in the 
 software itself an acknowledgement equivalent to the following:
     "This product includes software developed by
      Anthony Eden (http://www.anthonyeden.com/)."

 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR(S) BE LIABLE FOR ANY DIRECT, 
 INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES 
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR 
 SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) 
 HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, 
 STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING 
 IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 POSSIBILITY OF SUCH DAMAGE.

 For more information on JPublish, please see <http://www.jpublish.org/>.
 
 */

package org.jpublish.action;

import java.io.File;
import java.io.FileReader;

import javax.servlet.http.HttpSession;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.ibm.bsf.BSFManager;
import com.ibm.bsf.util.IOUtils;

import org.apache.velocity.VelocityContext;

import com.anthonyeden.lib.log.Logger;
import com.anthonyeden.lib.log.LogManager;

import org.jpublish.SiteContext;
import org.jpublish.util.LogSystem;

/**	An action which is implemented in a BSF supported scripting language.  Script
	actions have access to several varibles:
	
	<p>
	<b>vc</b> - The current Velocity context<br>
	<b>request</b> - The HTTP request<br>
	<b>response</b> - The HTTP response<br>
	<b>session</b> - The HTTP session<br>
	<b>syslog</b> - Standard logging stream (Log4J Category)
	</p>

	@author Anthony Eden
*/

public class ScriptAction implements Action{

	/**	Construct a new ScriptAction for the given script.  The path to the
		script should be an absolute path.
	
		@param siteContext The SiteContext
		@param script The path to the script
	*/

	public ScriptAction(SiteContext siteContext, String script){
		this(siteContext, new File(script));
	}
	
	/**	Construct a new ScriptAction for the given script.
	
		@param siteContext The SiteContext
		@param script The file representing the script
	*/

	public ScriptAction(SiteContext siteContext, File script){
		this.siteContext = siteContext;
		this.script = script;
	}
	
	/**	Execute the action script represented by this ScriptAction.
	
		@param context The current Velocity context
		@throws Exception
	*/

	public void execute(VelocityContext context) throws Exception{
		log.debug("Executing script: " + script);
		
		BSFManager bsfManager = new BSFManager();
		
		// expose standard items in the context
		if(context != null){
			HttpServletRequest request = (HttpServletRequest)context.get("request");
			HttpServletResponse response = (HttpServletResponse)context.get("response");
			HttpSession session = (HttpSession)context.get("session");
		
			bsfManager.declareBean("vc", context, VelocityContext.class);
			bsfManager.declareBean("request", request, HttpServletRequest.class);
			bsfManager.declareBean("response", response, HttpServletResponse.class);
			bsfManager.declareBean("session", session, HttpSession.class);
			bsfManager.declareBean("syslog", LogSystem.syslog, Logger.class);
		}
		
		bsfManager.declareBean("site", siteContext, SiteContext.class);
		
		bsfManager.exec(BSFManager.getLangFromFilename(script.getName()), 
			script.getName(), 0, 0, IOUtils.getStringFromReader(new FileReader(script)));
	}
	
	private static Logger log = LogManager.getLogger(ScriptAction.class.getName());
	
	private SiteContext siteContext;
	private File script;

}
