/*-- 

 Copyright (C) 2001 Anthony Eden.
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:
 
 1. Redistributions of source code must retain the above copyright
    notice, this list of conditions, and the following disclaimer.
 
 2. Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions, and the disclaimer that follows 
    these conditions in the documentation and/or other materials 
    provided with the distribution.

 3. The name "JPublish" must not be used to endorse or promote products
    derived from this software without prior written permission.  For
    written permission, please contact me@anthonyeden.com.
 
 4. Products derived from this software may not be called "JPublish", nor
    may "JPublish" appear in their name, without prior written permission
    from Anthony Eden (me@anthonyeden.com).
 
 In addition, I request (but do not require) that you include in the 
 end-user documentation provided with the redistribution and/or in the 
 software itself an acknowledgement equivalent to the following:
     "This product includes software developed by
      Anthony Eden (http://www.anthonyeden.com/)."

 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR(S) BE LIABLE FOR ANY DIRECT, 
 INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES 
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR 
 SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) 
 HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, 
 STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING 
 IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 POSSIBILITY OF SUCH DAMAGE.

 For more information on JPublish, please see <http://www.jpublish.org/>.
 
 */

package org.jpublish.servlet;

import java.util.Enumeration;

import javax.servlet.http.HttpSession;
import javax.servlet.http.HttpSessionContext;

/**	A concrete wrapper for the HttpSession interface.  This wrapper is
	required to be able to place the session into the Velocity context.

 	@author Anthony Eden
*/

public class HttpSessionWrap implements HttpSession{

	/**	Construct an HttpSessionWrap around the given session.

	 	@param session The HttpSession
	*/

	public HttpSessionWrap(HttpSession session){
		this.session = session;
	}

	/**	Get the creation time of the session.

	 	@return The creation time
	*/

	public long getCreationTime(){
		return session.getCreationTime();
	}

	/**	Get the session ID

	 	@return The session ID
	*/

	public String getId(){
		return session.getId();
	}
	
	public long getLastAccessedTime(){
		return session.getLastAccessedTime();
	}
	
	public boolean isNew(){
		return session.isNew();
	}
	
	public int getMaxInactiveInterval(){
		return session.getMaxInactiveInterval();
	}
	
	public void setMaxInactiveInterval(int interval){
		session.setMaxInactiveInterval(interval);
	}
	
	public Object getAttribute(String name){
		return session.getAttribute(name);
	}
	
	public Enumeration getAttributeNames(){
		return session.getAttributeNames();
	}
	
	public void setAttribute(String name, Object value){
		session.setAttribute(name, value);
	}
	
	public void removeAttribute(String name){
		session.removeAttribute(name);
	}
	
	public void invalidate(){
		session.invalidate();
	}
	
	/**
	
		@deprecated
	*/
	
	public Object getValue(String name){
		return session.getValue(name);
	}
	
	/**
	
		@deprecated
	*/
	
	public String[] getValueNames(){
		return session.getValueNames();
	}
	
	/**
	
		@deprecated
	*/
	
	public void putValue(String name, Object value){
		session.putValue(name, value);
	}
	
	/**
	
		@deprecated
	*/
	
	public void removeValue(String name){
		session.removeValue(name);
	}
	
	/**
	
		@deprecated
	*/
	
	public HttpSessionContext getSessionContext(){
		return session.getSessionContext();
	}
	
	private HttpSession session;

}
