/*-- 

 Copyright (C) 2001 Anthony Eden.
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:
 
 1. Redistributions of source code must retain the above copyright
    notice, this list of conditions, and the following disclaimer.
 
 2. Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions, and the disclaimer that follows 
    these conditions in the documentation and/or other materials 
    provided with the distribution.

 3. The name "JPublish" must not be used to endorse or promote products
    derived from this software without prior written permission.  For
    written permission, please contact me@anthonyeden.com.
 
 4. Products derived from this software may not be called "JPublish", nor
    may "JPublish" appear in their name, without prior written permission
    from Anthony Eden (me@anthonyeden.com).
 
 In addition, I request (but do not require) that you include in the 
 end-user documentation provided with the redistribution and/or in the 
 software itself an acknowledgement equivalent to the following:
     "This product includes software developed by
      Anthony Eden (http://www.anthonyeden.com/)."

 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR(S) BE LIABLE FOR ANY DIRECT, 
 INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES 
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR 
 SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) 
 HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, 
 STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING 
 IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 POSSIBILITY OF SUCH DAMAGE.

 For more information on JPublish, please see <http://www.jpublish.org/>.
 
 */

package org.jpublish.util;

import java.io.File;

import com.anthonyeden.lib.log.Logger;
import com.anthonyeden.lib.log.LogManager;

/** The log system will attempt to find the log properties file based on the 
	log path from the servlet init.  If the file cannot be found through this 
	method then it will look for it in the WEB-INF directory.  Finally if no 
	file can be found then it will use the BasicConfigurator.
	
	@author Anthony Eden
*/

public class LogSystem{

	/**	Construct and initialize the LogSystem.  The constructor will call
		reload() to attempt a first initialization.
		
		@param logPathFromInit The servlet init log path or null
		@param webInfFile The File representing the WEB-INF directory
	*/

	public LogSystem(String logPathFromInit, File webInfFile){
		this.logPathFromInit = logPathFromInit;
		this.webInfFile = webInfFile;
		load();
	}
	
	public void load(){
		if(logPathFromInit != null){
			this.logPropertiesFile = new File(logPathFromInit);
			if(logPropertiesFile.exists()){
				load(logPropertiesFile);
			} else {
				loadDefaultLogProperties();
			}
		} else {
			loadDefaultLogProperties();
		}
		
		syslog = LogManager.getLogger("syslog");
	}
	
	private void load(File logPropertiesFile){
		try{
			LogManager.setLoggerClassName("com.anthonyeden.lib.log.Log4JLogger");
			LogManager.configure(logPropertiesFile);
		} catch(Exception e){
			System.err.println("Error configuring LogManager");
			e.printStackTrace();
		}
		
		log = LogManager.getLogger(LogSystem.class.getName());
		log.info("Using log properties: " + logPropertiesFile);
	}
	
	private void loadDefaultLogProperties(){
		this.logPropertiesFile = new File(webInfFile, "log.properties");
		if(logPropertiesFile.exists()){
			load(logPropertiesFile);
		} else {
			try{
				LogManager.configure();
			} catch(Exception e){
				System.err.println("Error configuring LogManager");
				e.printStackTrace();
			}
			
			log = LogManager.getLogger(LogSystem.class.getName());
			log.debug("Using BasicConfigurator for logging setup.");
		}
	}
	
	public static Logger syslog;
	
	private static Logger log;
	
	private String logPathFromInit;
	private File webInfFile;
	private File logPropertiesFile;

}
