/*-- 

 Copyright (C) 2001 Anthony Eden.
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:
 
 1. Redistributions of source code must retain the above copyright
    notice, this list of conditions, and the following disclaimer.
 
 2. Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions, and the disclaimer that follows 
    these conditions in the documentation and/or other materials 
    provided with the distribution.

 3. The name "JPublish" must not be used to endorse or promote products
    derived from this software without prior written permission.  For
    written permission, please contact me@anthonyeden.com.
 
 4. Products derived from this software may not be called "JPublish", nor
    may "JPublish" appear in their name, without prior written permission
    from Anthony Eden (me@anthonyeden.com).
 
 In addition, I request (but do not require) that you include in the 
 end-user documentation provided with the redistribution and/or in the 
 software itself an acknowledgement equivalent to the following:
     "This product includes software developed by
      Anthony Eden (http://www.anthonyeden.com/)."

 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR(S) BE LIABLE FOR ANY DIRECT, 
 INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES 
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR 
 SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) 
 HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, 
 STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING 
 IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 POSSIBILITY OF SUCH DAMAGE.

 For more information on JPublish, please see <http://www.jpublish.org/>.
 
 */

package org.jpublish.util;

import java.util.HashMap;

/**	Data structure representing a mime type map.

	@author Anthony Eden
*/

public class MimeTypeMap extends HashMap{

	/**	Get the mime type for the given file extension.
	
		@return The mime type
	*/

	public String getMimeType(String extension){
		String mimeType = (String)get(extension);
		if(mimeType == null){
			return defaultMimeType;
		} else {
			return mimeType;
		}
	}
	
	/**	Get the default mime type.
	
		@return The default mime type
	*/
	
	public String getDefaultMimeType(){
		return defaultMimeType;
	}
	
	/**	Set the default mime type.
	
		@param defaultMimeType The new default mime type
	*/
	
	public void setDefaultMimeType(String defaultMimeType){
		if(defaultMimeType != null){
			this.defaultMimeType = defaultMimeType;
		} else {
			this.defaultMimeType = DEFAULT_MIME_TYPE;
		}
	}
	
	/**	The default mime type if none is set. */
	public static final String DEFAULT_MIME_TYPE = "application/octet-stream";
	
	private String defaultMimeType = DEFAULT_MIME_TYPE;

}
